# simple_neural_net

Minimal framework for creating a simple neural net

## Installation

`pip install simple-neural-net`

## Tasks
  * Consider changing shape of X and y inputs to match `sklearn` conventions
  * Add method which automatically evaluates model accuracy
  * Add cost model and prediction model for multi-class classification
  * Add other layer geometries (will require splitting up `Layer` class)
  * Add batching
